// Arup Guha
// 1/21/2013
// Solution to 2009 Greater NY Regional Problem G: Convex Hull of Lattice Points

import java.util.*;

public class g {

	public static void main(String[] args) {

		Scanner stdin = new Scanner(System.in);
		int numCases = stdin.nextInt();

		// Go through all the cases.
		for (int loop=1; loop<=numCases; loop++) {

			int dummy = stdin.nextInt();
			int n = stdin.nextInt();

			// Read in all points.
			pt[] all = new pt[n];
			for (int i=0; i<n; i++) {
				int x = stdin.nextInt();
				int y = stdin.nextInt();
				all[i] = new pt(x,y);
			}

			solve(all, loop);
		}

	}

	// Solves the convex hull for this case.
	public static void solve(pt[] all, int caseNum) {


		// Set up initial values.
		ArrayList<pt> hull = new ArrayList<pt>();

		// prev is previous point in the hull and next is the one to go to from prev.
		int prev = getStart(all);
		int start = prev;
		hull.add(all[prev]);
		int next = getNextPt(all, prev, 2*Math.PI+.1);

		// Repeatedly add points to the hull till we get back to the beginning point.
		while (next != start) {
			hull.add(all[next]);
			double angle = all[next].getAngle(all[prev]);
			prev = next;
			next = getNextPt(all, next, angle);
		}

		// Print out the result.
		System.out.println(caseNum+" "+hull.size());
		for (int i=0; i<hull.size(); i++)
			System.out.println(hull.get(i));
	}

	// Given the current point all[cur], the function returns x such that all[x]
	// is the next point in the convex hull, which is the point with the largest
	// angle that doesn't exceed maxAngle. If two points tie, the one that is
	// father from all[cur] is returned.
	public static int getNextPt(pt[] all, int cur, double maxAngle) {

		// Reset each point's relative angle to all[cur].
		for (int i=0; i<all.length; i++)
			all[i].setAngle(all[cur]);

		// Look for the best.
		int	best = -1;
		double curAngle = -1;
		for (int i=0; i<all.length; i++) {

			// These are invalid points to be next.
			if (i == cur) continue;
			if (all[i].angle > maxAngle-1e-10) continue;

			// Automatically replace best.
			if (best == -1) {
				best = i;
				curAngle = all[i].angle;
			}

			// Strictly better angle.
			else if ( all[i].angle > curAngle +1e-10) {
				best = i;
				curAngle = all[i].angle;
			}

			// Same angle case - check distance.
			else if (Math.abs(all[i].angle - curAngle) < 1e-10) {
				if (all[i].distance(all[cur]) > all[best].distance(all[cur])) {
					best = i;
					curAngle = all[i].angle;
				}
			}
		}

		// This is our next point.
		return best;
	}

	// Returns the point with the maximal y value, breaking ties with minimal x value.
	public static int getStart(pt[] all) {

		int best = 0;
		for (int i=1; i<all.length; i++) {

			if (all[i].y > all[best].y)
				best = i;
			else if (all[i].y == all[best].y && all[i].x < all[best].x)
				best = i;
		}
		return best;
	}
}

class pt {

	public int x;
	public int y;
	public double angle;

	public pt(int myx, int myy) {
		x = myx;
		y = myy;
	}

	// Sets this point's angle relative to origin, from 0 to 2pi.
	public void setAngle(pt origin) {
		angle = getAngle(origin);
	}

	// Returns this point's angle relative to origin, from 0 to 2pi.
	public double getAngle(pt origin) {
		if (this.equals(origin))
			return 0;
		else {
			double tmp = Math.atan2(this.y-origin.y, this.x-origin.x);
			if (tmp <= 0)
				tmp += (2*Math.PI);

			return tmp;
		}
	}

	public String toString() {
		return x+" "+y;
	}

	// Returns the distance between this and other.
	public double distance(pt other) {
		return Math.sqrt(Math.pow(this.x-other.x,2) + Math.pow(this.y-other.y,2));
	}
}